# Copyright:: Copyright 2015 杨晨晨.

require 'sketchup'
require 'extensions'
require('fileutils')

# This plugin provides extended support for all RBC plugins.
# All RBC plugins need to install the RBC Library!
#
# @creator:
#   杨晨晨(Sugar) - 932180146@qq.com
# @note:
#  * The RBC plugin uses RubyEncoder to protect the product.
#    RubyEncoder does not support Chinese file paths,
#    so try not to use the Chinese username.
#  * only support more than 2015 version!
#  * PC does not support less than 8 IE browsers.
#
# @since 7.0.0
module RBC

  file = __FILE__.force_encoding('UTF-8')
  unless file_loaded?(file) || defined?(RBC_EXTENSION)

    PLUGIN_PATH = __FILE__.force_encoding('UTF-8').freeze # LOADER FILE PATH
    RBC_NAME = 'RBC_Library'.freeze # Plugin NAME
    RBC_VERSION_ = [7, 2, 1].freeze # VERSION
    RBC_VERSION = RBC_VERSION_.join('.').freeze # VERSION_
    RBC_CREATE = '杨晨晨(Sugar)' # RBC_CREATE
    DIR_NAME = (RBC_NAME + '_v' + RBC_VERSION).freeze # MAIN DIRNAME
    RBC_CORE_DIR = File.join(File.dirname(PLUGIN_PATH), DIR_NAME).freeze # MAIN DIR

    # RBC EXTENSION.
    RBC_EXTENSION = SketchupExtension.new(RBC_NAME, File.join(RBC_CORE_DIR, 'core'))
    RBC_EXTENSION.version = RBC_VERSION
    RBC_EXTENSION.creator = RBC_CREATE
    RBC_EXTENSION.copyright = "Copyright (c) #{Time.new.year} Sugar All rights reserved."
    RBC_EXTENSION.description = 'This plugin provides extended support for all RBC plugins. All RBC plugins need to install the RBC extension library! (only support more than 2015 version!)email:932180146@qq.com'

    # check env.
    if Sketchup.version.to_i < 15
      error_tip = 'RBC Library Only supports more than 2015 versions!(只支持2015以上版本!)'
      Sketchup.status_text = error_tip
      if Sketchup.version.to_i >= 17
        n = UI::Notification.new(RBC_EXTENSION, error_tip, File.join(RBC_CORE_DIR, 'logo.png'), 'RBC')
        n.show
      else
        UI.messagebox(error_tip)
      end
    elsif __dir__.scan(/[\u4e00-\u9fa5]{1}/).length >= 1
      error_tip = 'RBC Library Only support English file paths!(只支持英语文件路径!)'
      Sketchup.status_text = error_tip
      if Sketchup.version.to_i >= 17
        n = UI::Notification.new(RBC_EXTENSION, error_tip, File.join(RBC_CORE_DIR, 'logo.png'), 'RBC')
        n.show
      else
        UI.messagebox(error_tip)
      end
    else
      Sketchup.register_extension(RBC_EXTENSION, true)
    end

    file_loaded(file)
  end # unless
end # module RBC

